Formatting the original spectral responses
------------------------------------------

Pyspectral defines a unified hdf5 format to hold the various sensor specific
relative spectral response functions.


.. include:: ../rsr_convert_scripts/README.rst
